import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:get/get.dart';
import 'package:get_storage/get_storage.dart';

class Response {
  late int code;
  String? message;
  dynamic data;

  Response({
    required this.code,
    this.message,
    this.data,
  });

  factory Response.fromJson(dynamic str) =>
      Response.fromMap(jsonDecode(str) as Map<String, dynamic>);

  factory Response.fromMap(Map<String, dynamic> resp) => Response(
        code: resp['code'],
        message: resp['message'],
        data: resp['data'],
      );
}

final client = GetPlatform.isAndroid ? 'android' : 'ios';

Dio createRequest() {
  var options = BaseOptions(
    baseUrl: 'http://192.168.89.147:7080/api/' + client + '/worker',
    // baseUrl: 'https://machine.njyunzhi.com/api/' + client + '/worker',
    connectTimeout: 5000,
    receiveTimeout: 3000,
  );

  var dio = Dio(options);
  dio.interceptors.add(InterceptorsWrapper(onRequest: (options, handler) {
    // Do something before request is sent
    options.headers['Authorization'] = GetStorage().read("token");
    return handler.next(options); //continue
  }, onResponse: (response, handler) {
    var resp = response.data as Map<String, dynamic>;
    if (resp['code'] == 1000) {
      response.data = resp['data'];

      try {
        var data = response.data as Map<String, dynamic>;
        if (null != data['token']) {
          GetStorage().write('token', data['token']); //取数据
        }
      } catch (e) {
        //
      }

      return handler.next(response);
    } else {
      DioError error = DioError(
          requestOptions: response.requestOptions,
          error: response.data,
          response: response);
      return handler.reject(error);
    }
  }, onError: (DioError e, handler) {
    return handler.next(e); //continue
  }));

  return dio;
}

var instance = createRequest();

Future request(String path,
    {data,
    Map<String, dynamic>? queryParameters,
    CancelToken? cancelToken,
    Options? options,
    ProgressCallback? onSendProgress,
    ProgressCallback? onReceiveProgress}) async {
  var resp = await instance.request(path,
      data: data,
      queryParameters: queryParameters,
      cancelToken: cancelToken,
      options: options);

  if (resp.data.runtimeType == String) {
    String dt = resp.data as String;
    dt.trim();
    if (dt.startsWith('{') && dt.endsWith('}')) {
      return jsonDecode(dt);
    }
    return dt;
  }

  return resp.data;
}
